@@ -1,5 +1,5 @@
 package Net::Async::Pusher::Channel;
-$Net::Async::Pusher::Channel::VERSION = '0.001';
+$Net::Async::Pusher::Channel::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -67,3 +67,13 @@ sub incoming_message {
 sub subscribed { $_[0]->{subscribed} //= $_[0]->loop->new_future }
 
 1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <TEAM@cpan.org>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2015-2016. Licensed under the same terms as Perl itself.
